@@ -81,12 +81,12 @@ class GatewayServer(threading.Thread):
       output = MessageToDict(raw_output, preserving_proto_field_name=True)
       return JSONResponse(output)
     except Exception as ex:
-      if '_state' in ex:
+      if hasattr(ex, '_state'):
         detail = ex._state.details
         grpc_status = ex._state.code.name
         http_status_code = self.get_http_status(StatusCode[grpc_status])
       else:
-        detail = str(ex)
+        detail = str(ex).replace('\n', ' ')
         http_status_code = 500
       raise HTTPException(http_status_code, detail=detail)
 
